@@ -1,5 +1,6 @@
 EST_ft = function(T0, nzt, vect0, ID, LEVELs, loadtype,
-                  MS, z0, c, nobs, nvar, ntv, nlv, nzct, const, W0,vb,alpha, varnames, A0)
+                  MS, z0, c, nobs, nvar, ntv, nlv, nzct, const, W0,vb,alpha, varnames, A0,
+                  num.factor, nInd)
 {
   ######################################################
   # INITIALIZATIONS - RANDOM STARTS
@@ -28,7 +29,7 @@ EST_ft = function(T0, nzt, vect0, ID, LEVELs, loadtype,
   }
   VV <- diag(VV)
 
-# 
+#
 #   V <- list()
 #   for(k in 1:c)
 #   {
@@ -36,13 +37,14 @@ EST_ft = function(T0, nzt, vect0, ID, LEVELs, loadtype,
 #   }
 
   V = lapply(W, function(x) cbind(VV, x))
-  
+
   ## input data Z (unstandized or STADANDIZED RAW DATA )
   bz0 <- z0     # ORIGINAL DATA
 
   ##############
 
-  AL_gscaLCA = al_gscaLCA(MS,z0, bz0, c, nobs, nvar, ntv,nlv, nzct, const,V, W,W0, T.mat,vb,alpha, A0)
+  AL_gscaLCA = al_gscaLCA(MS,z0, bz0, c, nobs, nvar, ntv, nlv, nzct, const, V, W, W0, T.mat,vb,alpha, A0,
+                          num.factor, nInd)
   U = AL_gscaLCA$U
   bi = AL_gscaLCA$bi
   f1 = AL_gscaLCA$f1
